@@ -18,27 +18,51 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import ChangeTypeType, DatasetKindType, locationTypeType
-from .paginator import ListChangesetsPaginator, ListDatasetsPaginator, ListDataViewsPaginator
+from .literals import (
+    ApiAccessType,
+    ApplicationPermissionType,
+    ChangeTypeType,
+    DatasetKindType,
+    UserTypeType,
+    locationTypeType,
+)
+from .paginator import (
+    ListChangesetsPaginator,
+    ListDatasetsPaginator,
+    ListDataViewsPaginator,
+    ListPermissionGroupsPaginator,
+    ListUsersPaginator,
+)
 from .type_defs import (
     CreateChangesetResponseTypeDef,
     CreateDatasetResponseTypeDef,
     CreateDataViewResponseTypeDef,
+    CreatePermissionGroupResponseTypeDef,
+    CreateUserResponseTypeDef,
     DatasetOwnerInfoTypeDef,
     DataViewDestinationTypeParamsTypeDef,
     DeleteDatasetResponseTypeDef,
+    DeletePermissionGroupResponseTypeDef,
+    DisableUserResponseTypeDef,
+    EnableUserResponseTypeDef,
     GetChangesetResponseTypeDef,
     GetDatasetResponseTypeDef,
     GetDataViewResponseTypeDef,
     GetProgrammaticAccessCredentialsResponseTypeDef,
+    GetUserResponseTypeDef,
     GetWorkingLocationResponseTypeDef,
     ListChangesetsResponseTypeDef,
     ListDatasetsResponseTypeDef,
     ListDataViewsResponseTypeDef,
+    ListPermissionGroupsResponseTypeDef,
+    ListUsersResponseTypeDef,
     PermissionGroupParamsTypeDef,
+    ResetUserPasswordResponseTypeDef,
     SchemaUnionTypeDef,
     UpdateChangesetResponseTypeDef,
     UpdateDatasetResponseTypeDef,
+    UpdatePermissionGroupResponseTypeDef,
+    UpdateUserResponseTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -147,6 +171,40 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_dataset)
         """
 
+    def create_permission_group(
+        self,
+        *,
+        name: str,
+        applicationPermissions: Sequence[ApplicationPermissionType],
+        description: str = ...,
+        clientToken: str = ...
+    ) -> CreatePermissionGroupResponseTypeDef:
+        """
+        Creates a group of permissions for various actions that a user can perform in
+        FinSpace.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.create_permission_group)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_permission_group)
+        """
+
+    def create_user(
+        self,
+        *,
+        emailAddress: str,
+        type: UserTypeType,
+        firstName: str = ...,
+        lastName: str = ...,
+        ApiAccess: ApiAccessType = ...,
+        apiAccessPrincipalArn: str = ...,
+        clientToken: str = ...
+    ) -> CreateUserResponseTypeDef:
+        """
+        Creates a new user in FinSpace.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.create_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_user)
+        """
+
     def delete_dataset(
         self, *, datasetId: str, clientToken: str = ...
     ) -> DeleteDatasetResponseTypeDef:
@@ -157,6 +215,32 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#delete_dataset)
         """
 
+    def delete_permission_group(
+        self, *, permissionGroupId: str, clientToken: str = ...
+    ) -> DeletePermissionGroupResponseTypeDef:
+        """
+        Deletes a permission group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.delete_permission_group)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#delete_permission_group)
+        """
+
+    def disable_user(self, *, userId: str, clientToken: str = ...) -> DisableUserResponseTypeDef:
+        """
+        Denies access to the FinSpace web application and API for the specified user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.disable_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#disable_user)
+        """
+
+    def enable_user(self, *, userId: str, clientToken: str = ...) -> EnableUserResponseTypeDef:
+        """
+        Allows the specified user to access the FinSpace web application and API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.enable_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#enable_user)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -205,6 +289,14 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
+    def get_user(self, *, userId: str) -> GetUserResponseTypeDef:
+        """
+        Retrieves details for a specific user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_user)
+        """
+
     def get_working_location(
         self, *, locationType: locationTypeType = ...
     ) -> GetWorkingLocationResponseTypeDef:
@@ -246,6 +338,34 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_datasets)
         """
 
+    def list_permission_groups(
+        self, *, maxResults: int, nextToken: str = ...
+    ) -> ListPermissionGroupsResponseTypeDef:
+        """
+        Lists all available permission groups in FinSpace.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.list_permission_groups)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_permission_groups)
+        """
+
+    def list_users(self, *, maxResults: int, nextToken: str = ...) -> ListUsersResponseTypeDef:
+        """
+        Lists all available user accounts in FinSpace.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.list_users)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#list_users)
+        """
+
+    def reset_user_password(
+        self, *, userId: str, clientToken: str = ...
+    ) -> ResetUserPasswordResponseTypeDef:
+        """
+        Resets the password for a specified user ID and generates a temporary one.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.reset_user_password)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#reset_user_password)
+        """
+
     def update_changeset(
         self,
         *,
@@ -280,6 +400,40 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#update_dataset)
         """
 
+    def update_permission_group(
+        self,
+        *,
+        permissionGroupId: str,
+        name: str = ...,
+        description: str = ...,
+        applicationPermissions: Sequence[ApplicationPermissionType] = ...,
+        clientToken: str = ...
+    ) -> UpdatePermissionGroupResponseTypeDef:
+        """
+        Modifies the details of a permission group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.update_permission_group)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#update_permission_group)
+        """
+
+    def update_user(
+        self,
+        *,
+        userId: str,
+        type: UserTypeType = ...,
+        firstName: str = ...,
+        lastName: str = ...,
+        apiAccess: ApiAccessType = ...,
+        apiAccessPrincipalArn: str = ...,
+        clientToken: str = ...
+    ) -> UpdateUserResponseTypeDef:
+        """
+        Modifies the details of the specified user account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.update_user)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#update_user)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_changesets"]) -> ListChangesetsPaginator:
         """
@@ -300,3 +454,19 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_paginator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_paginator)
         """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_permission_groups"]
+    ) -> ListPermissionGroupsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_users"]) -> ListUsersPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_paginator)
+        """
