@@ -6,9 +6,9 @@ Type annotations for finspace-data service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_finspace_data.literals import ChangeTypeType
+    from mypy_boto3_finspace_data.literals import ApiAccessType
 
-    data: ChangeTypeType = "APPEND"
+    data: ApiAccessType = "DISABLED"
     ```
 """
 import sys
@@ -20,6 +20,8 @@ else:
 
 
 __all__ = (
+    "ApiAccessType",
+    "ApplicationPermissionType",
     "ChangeTypeType",
     "ColumnDataTypeType",
     "DataViewStatusType",
@@ -31,12 +33,26 @@ __all__ = (
     "ListChangesetsPaginatorName",
     "ListDataViewsPaginatorName",
     "ListDatasetsPaginatorName",
+    "ListPermissionGroupsPaginatorName",
+    "ListUsersPaginatorName",
+    "UserStatusType",
+    "UserTypeType",
     "locationTypeType",
     "ServiceName",
     "PaginatorName",
 )
 
 
+ApiAccessType = Literal["DISABLED", "ENABLED"]
+ApplicationPermissionType = Literal[
+    "AccessNotebooks",
+    "CreateDataset",
+    "GetTemporaryCredentials",
+    "ManageAttributeSets",
+    "ManageClusters",
+    "ManageUsersAndGroups",
+    "ViewAuditData",
+]
 ChangeTypeType = Literal["APPEND", "MODIFY", "REPLACE"]
 ColumnDataTypeType = Literal[
     "BIGINT",
@@ -79,6 +95,10 @@ IngestionStatusType = Literal["FAILED", "PENDING", "RUNNING", "STOP_REQUESTED",
 ListChangesetsPaginatorName = Literal["list_changesets"]
 ListDataViewsPaginatorName = Literal["list_data_views"]
 ListDatasetsPaginatorName = Literal["list_datasets"]
+ListPermissionGroupsPaginatorName = Literal["list_permission_groups"]
+ListUsersPaginatorName = Literal["list_users"]
+UserStatusType = Literal["CREATING", "DISABLED", "ENABLED"]
+UserTypeType = Literal["APP_USER", "SUPER_USER"]
 locationTypeType = Literal["INGESTION", "SAGEMAKER"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -381,4 +401,6 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
-PaginatorName = Literal["list_changesets", "list_data_views", "list_datasets"]
+PaginatorName = Literal[
+    "list_changesets", "list_data_views", "list_datasets", "list_permission_groups", "list_users"
+]
