@@ -15,6 +15,8 @@ import sys
 from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
+    ApiAccessType,
+    ApplicationPermissionType,
     ChangeTypeType,
     ColumnDataTypeType,
     DatasetKindType,
@@ -23,6 +25,8 @@ from .literals import (
     ErrorCategoryType,
     ExportFileFormatType,
     IngestionStatusType,
+    UserStatusType,
+    UserTypeType,
     locationTypeType,
 )
 
@@ -42,6 +46,10 @@ __all__ = (
     "CreateDataViewResponseTypeDef",
     "CreateDatasetRequestRequestTypeDef",
     "CreateDatasetResponseTypeDef",
+    "CreatePermissionGroupRequestRequestTypeDef",
+    "CreatePermissionGroupResponseTypeDef",
+    "CreateUserRequestRequestTypeDef",
+    "CreateUserResponseTypeDef",
     "CredentialsTypeDef",
     "DataViewDestinationTypeParamsTypeDef",
     "DataViewErrorInfoTypeDef",
@@ -50,6 +58,12 @@ __all__ = (
     "DatasetTypeDef",
     "DeleteDatasetRequestRequestTypeDef",
     "DeleteDatasetResponseTypeDef",
+    "DeletePermissionGroupRequestRequestTypeDef",
+    "DeletePermissionGroupResponseTypeDef",
+    "DisableUserRequestRequestTypeDef",
+    "DisableUserResponseTypeDef",
+    "EnableUserRequestRequestTypeDef",
+    "EnableUserResponseTypeDef",
     "GetChangesetRequestRequestTypeDef",
     "GetChangesetResponseTypeDef",
     "GetDataViewRequestRequestTypeDef",
@@ -58,6 +72,8 @@ __all__ = (
     "GetDatasetResponseTypeDef",
     "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
     "GetProgrammaticAccessCredentialsResponseTypeDef",
+    "GetUserRequestRequestTypeDef",
+    "GetUserResponseTypeDef",
     "GetWorkingLocationRequestRequestTypeDef",
     "GetWorkingLocationResponseTypeDef",
     "ListChangesetsRequestRequestTypeDef",
@@ -66,8 +82,15 @@ __all__ = (
     "ListDataViewsResponseTypeDef",
     "ListDatasetsRequestRequestTypeDef",
     "ListDatasetsResponseTypeDef",
+    "ListPermissionGroupsRequestRequestTypeDef",
+    "ListPermissionGroupsResponseTypeDef",
+    "ListUsersRequestRequestTypeDef",
+    "ListUsersResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PermissionGroupParamsTypeDef",
+    "PermissionGroupTypeDef",
+    "ResetUserPasswordRequestRequestTypeDef",
+    "ResetUserPasswordResponseTypeDef",
     "ResourcePermissionTypeDef",
     "ResponseMetadataTypeDef",
     "SchemaDefinitionTypeDef",
@@ -76,6 +99,11 @@ __all__ = (
     "UpdateChangesetResponseTypeDef",
     "UpdateDatasetRequestRequestTypeDef",
     "UpdateDatasetResponseTypeDef",
+    "UpdatePermissionGroupRequestRequestTypeDef",
+    "UpdatePermissionGroupResponseTypeDef",
+    "UpdateUserRequestRequestTypeDef",
+    "UpdateUserResponseTypeDef",
+    "UserTypeDef",
 )
 
 ChangesetErrorInfoTypeDef = TypedDict(
@@ -220,6 +248,72 @@ CreateDatasetResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePermissionGroupRequestRequestTypeDef",
+    {
+        "name": str,
+        "applicationPermissions": Sequence[ApplicationPermissionType],
+    },
+)
+_OptionalCreatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePermissionGroupRequestRequestTypeDef",
+    {
+        "description": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreatePermissionGroupRequestRequestTypeDef(
+    _RequiredCreatePermissionGroupRequestRequestTypeDef,
+    _OptionalCreatePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+CreatePermissionGroupResponseTypeDef = TypedDict(
+    "CreatePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateUserRequestRequestTypeDef",
+    {
+        "emailAddress": str,
+        "type": UserTypeType,
+    },
+)
+_OptionalCreateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateUserRequestRequestTypeDef",
+    {
+        "firstName": str,
+        "lastName": str,
+        "ApiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateUserRequestRequestTypeDef(
+    _RequiredCreateUserRequestRequestTypeDef, _OptionalCreateUserRequestRequestTypeDef
+):
+    pass
+
+
+CreateUserResponseTypeDef = TypedDict(
+    "CreateUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CredentialsTypeDef = TypedDict(
     "CredentialsTypeDef",
     {
@@ -336,6 +430,94 @@ DeleteDatasetResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredDeletePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredDeletePermissionGroupRequestRequestTypeDef",
+    {
+        "permissionGroupId": str,
+    },
+)
+_OptionalDeletePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalDeletePermissionGroupRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeletePermissionGroupRequestRequestTypeDef(
+    _RequiredDeletePermissionGroupRequestRequestTypeDef,
+    _OptionalDeletePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+DeletePermissionGroupResponseTypeDef = TypedDict(
+    "DeletePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDisableUserRequestRequestTypeDef = TypedDict(
+    "_RequiredDisableUserRequestRequestTypeDef",
+    {
+        "userId": str,
+    },
+)
+_OptionalDisableUserRequestRequestTypeDef = TypedDict(
+    "_OptionalDisableUserRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DisableUserRequestRequestTypeDef(
+    _RequiredDisableUserRequestRequestTypeDef, _OptionalDisableUserRequestRequestTypeDef
+):
+    pass
+
+
+DisableUserResponseTypeDef = TypedDict(
+    "DisableUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredEnableUserRequestRequestTypeDef = TypedDict(
+    "_RequiredEnableUserRequestRequestTypeDef",
+    {
+        "userId": str,
+    },
+)
+_OptionalEnableUserRequestRequestTypeDef = TypedDict(
+    "_OptionalEnableUserRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class EnableUserRequestRequestTypeDef(
+    _RequiredEnableUserRequestRequestTypeDef, _OptionalEnableUserRequestRequestTypeDef
+):
+    pass
+
+
+EnableUserResponseTypeDef = TypedDict(
+    "EnableUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetChangesetRequestRequestTypeDef = TypedDict(
     "GetChangesetRequestRequestTypeDef",
     {
@@ -446,6 +628,33 @@ GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
     },
 )
 
+GetUserRequestRequestTypeDef = TypedDict(
+    "GetUserRequestRequestTypeDef",
+    {
+        "userId": str,
+    },
+)
+
+GetUserResponseTypeDef = TypedDict(
+    "GetUserResponseTypeDef",
+    {
+        "userId": str,
+        "status": UserStatusType,
+        "firstName": str,
+        "lastName": str,
+        "emailAddress": str,
+        "type": UserTypeType,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "createTime": int,
+        "lastEnabledTime": int,
+        "lastDisabledTime": int,
+        "lastModifiedTime": int,
+        "lastLoginTime": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetWorkingLocationRequestRequestTypeDef = TypedDict(
     "GetWorkingLocationRequestRequestTypeDef",
     {
@@ -544,6 +753,67 @@ ListDatasetsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListPermissionGroupsRequestRequestTypeDef = TypedDict(
+    "_RequiredListPermissionGroupsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+    },
+)
+_OptionalListPermissionGroupsRequestRequestTypeDef = TypedDict(
+    "_OptionalListPermissionGroupsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListPermissionGroupsRequestRequestTypeDef(
+    _RequiredListPermissionGroupsRequestRequestTypeDef,
+    _OptionalListPermissionGroupsRequestRequestTypeDef,
+):
+    pass
+
+
+ListPermissionGroupsResponseTypeDef = TypedDict(
+    "ListPermissionGroupsResponseTypeDef",
+    {
+        "permissionGroups": List["PermissionGroupTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListUsersRequestRequestTypeDef = TypedDict(
+    "_RequiredListUsersRequestRequestTypeDef",
+    {
+        "maxResults": int,
+    },
+)
+_OptionalListUsersRequestRequestTypeDef = TypedDict(
+    "_OptionalListUsersRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListUsersRequestRequestTypeDef(
+    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
+):
+    pass
+
+
+ListUsersResponseTypeDef = TypedDict(
+    "ListUsersResponseTypeDef",
+    {
+        "users": List["UserTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -563,6 +833,49 @@ PermissionGroupParamsTypeDef = TypedDict(
     total=False,
 )
 
+PermissionGroupTypeDef = TypedDict(
+    "PermissionGroupTypeDef",
+    {
+        "permissionGroupId": str,
+        "name": str,
+        "description": str,
+        "applicationPermissions": List[ApplicationPermissionType],
+        "createTime": int,
+        "lastModifiedTime": int,
+    },
+    total=False,
+)
+
+_RequiredResetUserPasswordRequestRequestTypeDef = TypedDict(
+    "_RequiredResetUserPasswordRequestRequestTypeDef",
+    {
+        "userId": str,
+    },
+)
+_OptionalResetUserPasswordRequestRequestTypeDef = TypedDict(
+    "_OptionalResetUserPasswordRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class ResetUserPasswordRequestRequestTypeDef(
+    _RequiredResetUserPasswordRequestRequestTypeDef, _OptionalResetUserPasswordRequestRequestTypeDef
+):
+    pass
+
+
+ResetUserPasswordResponseTypeDef = TypedDict(
+    "ResetUserPasswordResponseTypeDef",
+    {
+        "userId": str,
+        "temporaryPassword": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ResourcePermissionTypeDef = TypedDict(
     "ResourcePermissionTypeDef",
     {
@@ -665,3 +978,90 @@ UpdateDatasetResponseTypeDef = TypedDict(
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
+
+_RequiredUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePermissionGroupRequestRequestTypeDef",
+    {
+        "permissionGroupId": str,
+    },
+)
+_OptionalUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePermissionGroupRequestRequestTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "applicationPermissions": Sequence[ApplicationPermissionType],
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdatePermissionGroupRequestRequestTypeDef(
+    _RequiredUpdatePermissionGroupRequestRequestTypeDef,
+    _OptionalUpdatePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+UpdatePermissionGroupResponseTypeDef = TypedDict(
+    "UpdatePermissionGroupResponseTypeDef",
+    {
+        "permissionGroupId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateUserRequestRequestTypeDef",
+    {
+        "userId": str,
+    },
+)
+_OptionalUpdateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateUserRequestRequestTypeDef",
+    {
+        "type": UserTypeType,
+        "firstName": str,
+        "lastName": str,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateUserRequestRequestTypeDef(
+    _RequiredUpdateUserRequestRequestTypeDef, _OptionalUpdateUserRequestRequestTypeDef
+):
+    pass
+
+
+UpdateUserResponseTypeDef = TypedDict(
+    "UpdateUserResponseTypeDef",
+    {
+        "userId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UserTypeDef = TypedDict(
+    "UserTypeDef",
+    {
+        "userId": str,
+        "status": UserStatusType,
+        "firstName": str,
+        "lastName": str,
+        "emailAddress": str,
+        "type": UserTypeType,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "createTime": int,
+        "lastEnabledTime": int,
+        "lastDisabledTime": int,
+        "lastModifiedTime": int,
+        "lastLoginTime": int,
+    },
+    total=False,
+)
